tietools.remove_tie_spanners_from_components_in_expr
====================================================

.. autofunction:: abjad.tools.tietools.remove_tie_spanners_from_components_in_expr.remove_tie_spanners_from_components_in_expr
